﻿Imports System.Drawing
Imports vmAPI

Public Class SamplePlugin
    Implements vmInterface

    ' Timer (only used for the demo)
    Private myTimer As Timers.Timer

    ' This region is required
#Region "vmInterface"
    Public ReadOnly Property DisplayName As String Implements vmInterface.DisplayName
        Get
            DisplayName = "My Sample Plugin" ' the Name of your plugin displayed in VoiceMacro
        End Get
    End Property

    Public ReadOnly Property Description As String Implements vmInterface.Description
        Get
            Description = "My Sample Plugin Description" ' description of your plugin
        End Get
    End Property

    Public ReadOnly Property ID As String Implements vmInterface.ID
        ' Unique ID for your plugin, get your GUID from https://www.guidgen.com/
        Get
            ID = "c536f9fb-1b1c-4abf-819a-bdc64ab7e2e7"
        End Get
    End Property

    ' This is started when your plugin is activated
    Public Sub Init() Implements vmInterface.Init
        ' Do some sample interfacing
        DoSomeInterfacing()
    End Sub

    ' This is invoked when you use SendToPlugin action
    Public Sub ReceiveParams(ByVal Param1 As String, ByVal Param2 As String, ByVal Param3 As String, ByVal Synchron As Boolean) Implements vmInterface.ReceiveParams
        ' Write received Parameters to Log
        vmCommand.AddLogEntry("Sample plugin received new Parameters, Param1: " & Param1 & " / Param2: " & Param2 & " / Param3: " & Param3, Color.DeepPink, ID)
    End Sub

    ' This is invoked when a profile is switched
    Public Sub ProfileSwitched(ByVal ProfileGUID As String, ByVal ProfileName As String) Implements vmInterface.ProfileSwitched
        ' Write info to Log
        vmCommand.AddLogEntry("Sample plugin received profile switching to profile " & ProfileName, Color.Black, ID)
    End Sub

    ' This is started when VoiceMacro is terminated
    Public Sub Dispose() Implements vmInterface.Dispose
        ' Stop activities because VoiceMacro is shutting down
        If myTimer IsNot Nothing Then myTimer.Stop()
    End Sub
#End Region

    Private Sub DoSomeInterfacing()
        '
        ' Set a variable
        '
        vmCommand.SetVariable("test_g", "Hello World")


        '
        ' Get a variable
        '
        Dim MyVariable As String = vmCommand.GetVariable("test_g")


        '
        ' Show variable in VoiceMacro's log in PINK
        '
        vmCommand.AddLogEntry(MyVariable & " from sample plugin!", Color.DeepPink, ID)

        '
        ' Add log entry with sign, and also show text in Status bar
        '
        vmCommand.AddLogEntry("I can haz my own signs", Color.Black, ID, "i", "Hello status bar from Plugin!")

        '
        ' Get profiles/macros and print them to log
        '
        Dim myProfiles As List(Of vmProfile) = vmCommand.GetProfiles

        '
        ' Write each profile name and macros (commands) to log
        '
        vmCommand.AddLogEntry("Timestart", Color.Yellow, ID, "*")
        For a = myProfiles.Count - 1 To 0 Step -1 ' reverse the order when writing to log because new entries are added on top

            If myProfiles(a).Commands Is Nothing Then Continue For ' skip empty commands lists


            For x = myProfiles(a).Commands.Count - 1 To 0 Step -1
                vmCommand.AddLogEntry("  Command: " & myProfiles(a).Commands(x).RecocnitionText, Color.BlueViolet, ID)
            Next x


            ' Note: If we want this on top of the macros list in the Log, we have to send it last
            vmCommand.AddLogEntry("Profile: " & myProfiles(a).ProfileName, Color.Blue, ID)
        Next a
        vmCommand.AddLogEntry("Timestop", Color.Yellow, ID, "*")


        '
        ' Start a macro by Profile/Macro GUID
        '
        If vmCommand.ExecuteMacro("414bb82f-12e0-427d-bf7c-712288d03142/28fdfdf2-1502-4bf0-9ace-d6649d921f32") = True Then
            ' Macro found and started
        Else
            ' Macro not found!
        End If

        '
        ' Get Profile/Macro GUID by command name and execute it
        '
        Dim myCommand As String = vmCommand.CommandExists("My sample plugin command")
        If myCommand IsNot Nothing Then
            vmCommand.ExecuteMacro(myCommand)
        Else
            vmCommand.AddLogEntry("Error: Macro ""My sample plugin command"" not found!", Color.Red, ID)
        End If

        '
        ' Gets VoiceMacro's Data directory
        '
        vmCommand.AddLogEntry("Data Directory is: " & vmCommand.GetDataDirectory(), Color.DarkGreen, ID)


        '
        ' Get Active Profile GUID and write it in Log
        '
        vmCommand.AddLogEntry("Active Profile GUID: " & vmCommand.GetActiveProfileGUID, Color.DarkRed, ID)

        '
        ' Start a timer and spam that log!
        '
        Threading.Thread.Sleep(4000)
        myTimer = New Timers.Timer(20)
        AddHandler myTimer.Elapsed, AddressOf Timer_Elapsed
        myTimer.Start()

    End Sub

    Dim count As Integer = 1

    Public Sub Timer_Elapsed()
        '
        ' Spam in VoiceMacro's log in PINK
        '
        'Dim MyVariable As String = vmCommand.GetVariable("test_g")

        count += 1
        If count > 50 Then myTimer.Stop()

        '
        ' Send a key (Capital S with Shift + s)
        '
        ' Uncomment to test!
        '
        'Dim myKey As KeyboardAction = New KeyboardAction
        'Dim myKey2 As KeyboardAction = New KeyboardAction
        'Dim myKey3 As KeyboardAction = New KeyboardAction
        ''myKey.Key = Windows.Forms.Keys.S
        'myKey.lShift = True
        'myKey.ClickDownUp = 1 ' (0 = Click, 1 = Down, 2 = Up)
        ''myKey.ClickDuration = 25 ' 25ms click duration
        'vmCommand.SendKey(myKey)
        'myKey2.Key = Windows.Forms.Keys.S
        'myKey2.ClickDownUp = 1
        'vmCommand.SendKey(myKey2)
        'myKey2.ClickDownUp = 2
        'vmCommand.SendKey(myKey2)
        'myKey3.lShift = True
        'myKey3.ClickDownUp = 2
        'vmCommand.SendKey(myKey3)

        If vmCommand.AddLogEntry("Spam from sample plugin! " & MyVariable, Color.DeepPink, ID) = False Then
            myTimer.Stop()
        End If
    End Sub
End Class

